/* iip.h - Inline Images Protocol */
/* Created: Sat Nov 18 09:41:36 AM EST 2023 malakai */
/* Copyright © 1991-2023 The Last Outpost Project */
/* $Id: iip.h,v 1.1 2023/11/18 19:24:19 malakai Exp $ */

/* Copyright © 2023 Rahjiii <rahjiii@jeffrika.com>
 *
 * This file is part of iip - Last Outpost Inline Images Protocol
 *
 * iip is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * iip is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Locolor.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef LO_IIP_H
#define LO_IIP_H

/* ---- global #defines ---- */

/* ---- structs and typedefs ---- */
/* You are expected to change this typedef to match the descriptor format of
 * your own raw_output implementation. See the comment in iip.c near
 * iip_raw_output() */
typedef struct descriptor_data* iip_descriptor_t;

/* The units used in the IIP protocol for width and height specification. */
typedef enum {
	IIP_UNIT_NONE,
	IIP_UNIT_CELLS,
	IIP_UNIT_PIXELS,
	IIP_UNIT_PERCENT,
	IIP_UNIT_AUTO,
	IIP_UNIT_MAX
} iip_units_t;

/* This is a structure containing an encoded image and all of its display
 * options. */
typedef struct {
	gchar *filename;    /* Copy of the local filename. */
	gchar *encoded;     /* base64 encoded image data. */
	gsize size;         /* The size of the pre-encoded image data. */
	gboolean display;   /* TRUE means display inline. */
	gint width;         /* How wide should the image display? */
	iip_units_t widthu; /* ...and with what units? */
	gint height;        /* How tall should the image display? */
	iip_units_t heightu; /* ...and with what units? */
	gboolean preserveAspectRatio; /* Use FALSE to allow stretching. */
	gchar *name;        /* not used for inline images. */
	gchar *type;        /* not typically used at all? */
} iip_data_t;

/* ---- exported global variable declarations ---- */

/* ---- exported function declarations ---- */
iip_data_t *iip_file_get_contents(gchar *filename);
iip_data_t *new_iip_data(void);
void free_iip_data(iip_data_t *n);
void iip_output(iip_data_t *image, iip_descriptor_t d);

#endif /* LO_IIP_H */
